pub fn init_env_logger()Expand description
Set up the environmental (env) logger with our format
Ensure that the lines and module paths are printed in the logging output
pub fn init_env_logger()Set up the environmental (env) logger with our format
Ensure that the lines and module paths are printed in the logging output